@@ -287,6 +287,16 @@ class TrainingStep(ConfigurableRetryStep):
             )
             warnings.warn(msg)
 
+        self.job_name = None
+        if estimator.source_dir or estimator.entry_point:
+            # By default, `Estimator` will upload the local code to an S3 path
+            # containing a timestamp. This causes cache misses whenever a
+            # pipeline is updated, even if the underlying script hasn't changed.
+            # To avoid this, hash the contents of the training script and include it
+            # in the `job_name` passed to the `Estimator`, which will be used
+            # instead of the timestamped path.
+            self.job_name = self._generate_code_upload_path()
+
     @property
     def arguments(self) -> RequestType:
         """The arguments dictionary that is used to call `create_training_job`.
@@ -295,7 +305,7 @@ class TrainingStep(ConfigurableRetryStep):
         The `TrainingJobName` and `ExperimentConfig` attributes cannot be included.
         """
 
-        self.estimator._prepare_for_training()
+        self.estimator._prepare_for_training(self.job_name)
         train_args = _TrainingJob._get_train_args(
             self.estimator, self.inputs, experiment_config=dict()
         )
@@ -319,6 +329,26 @@ class TrainingStep(ConfigurableRetryStep):
 
         return request_dict
 
+    def _generate_code_upload_path(self) -> str or None:
+        """Generate an upload path for local training scripts based on their content."""
+        from sagemaker.workflow.utilities import hash_files_or_dirs
+
+        if self.estimator.source_dir:
+            source_dir_url = urlparse(self.estimator.source_dir)
+            if source_dir_url.scheme == "" or source_dir_url.scheme == "file":
+                code_hash = hash_files_or_dirs(
+                    [self.estimator.source_dir] + self.estimator.dependencies
+                )
+                return f"{self.name}-{code_hash}"[:1024]
+        elif self.estimator.entry_point:
+            entry_point_url = urlparse(self.estimator.entry_point)
+            if entry_point_url.scheme == "" or entry_point_url.scheme == "file":
+                code_hash = hash_files_or_dirs(
+                    [self.estimator.entry_point] + self.estimator.dependencies
+                )
+                return f"{self.name}-{code_hash}"[:1024]
+        return None
+
 
 class CreateModelStep(ConfigurableRetryStep):
     """`CreateModelStep` for SageMaker Pipelines Workflows."""
